@@ -18,7 +18,7 @@ ax = Axes3D(fig, azim = -29, elev = 40)
 X = np.arange(-50, 50, 0.5)
 Y = np.arange(-50, 50, 0.5)
 X, Y = np.meshgrid(X, Y)
-Z = np.fromiter(map(griewank_arg0, zip(X.flat,Y.flat)), dtype=np.float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
+Z = np.fromiter(map(griewank_arg0, zip(X.flat,Y.flat)), dtype=float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
 
 ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.jet, linewidth=0.2)
 
