@@ -17,7 +17,7 @@ ax = Axes3D(fig, azim = -29, elev = 50)
 X = np.arange(-5, 5, 0.1)
 Y = np.arange(-5, 5, 0.1)
 X, Y = np.meshgrid(X, Y)
-Z = np.fromiter(map(rastrigin_arg0, zip(X.flat,Y.flat)), dtype=np.float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
+Z = np.fromiter(map(rastrigin_arg0, zip(X.flat,Y.flat)), dtype=float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
 
 ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.jet, linewidth=0.2)
 
