@@ -19,7 +19,7 @@ ax = Axes3D(fig)
 X = np.arange(-2, 2, 0.1)
 Y = np.arange(-1, 3, 0.1)
 X, Y = np.meshgrid(X, Y)
-Z = np.fromiter(map(rosenbrock_arg0, zip(X.flat,Y.flat)), dtype=np.float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
+Z = np.fromiter(map(rosenbrock_arg0, zip(X.flat,Y.flat)), dtype=float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
 
 ax.plot_surface(X, Y, Z, rstride=1, cstride=1,  norm=LogNorm(), cmap=cm.jet, linewidth=0.2)
 
