@@ -26,7 +26,7 @@ ax = Axes3D(fig)
 X = np.arange(0, 1, 0.01)
 Y = np.arange(0, 1, 0.01)
 X, Y = np.meshgrid(X, Y)
-Z = np.fromiter(map(shekel_arg0, zip(X.flat,Y.flat)), dtype=np.float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
+Z = np.fromiter(map(shekel_arg0, zip(X.flat,Y.flat)), dtype=float, count=X.shape[0]*X.shape[1]).reshape(X.shape)
 
 ax.plot_surface(X, Y, Z, rstride=1, cstride=1,  norm=LogNorm(), cmap=cm.jet, linewidth=0.2)
 
